Enum EndEffectStrategy
#[non_exhaustive]pub enum EndEffectStrategy {
LinearSlope,
MirrorExtrema {
num_extrema: usize,
},
SymmetricExtension {
num_extrema: usize,
},
AutoRegressive {
order: usize,
extension_length: usize,
},
}Expand description
Strategy used to mitigate envelope end effects during EMD sifting.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LinearSlope
Linearly extrapolate each boundary from the two nearest extrema.
MirrorExtrema
Position-reflect the num_extrema nearest extrema around each boundary
(x → −x on the left, x → 2(n−1) − x on the right) and add them to the
spline knot set with their original y values. Rilling, Flandrin &
Gonçalves (2003) III.
SymmetricExtension
Like Self::MirrorExtrema but with value-symmetric y values:
y = 2·data[boundary] − data[extremum]. Zeng & He (2004).
AutoRegressive
Fit an AR(p) model and extend the signal extension_length samples on
each side before extrema detection. Dätig & Schlurmann (2004).