Struct EEMD
pub struct EEMD {
pub ensemble_size: usize,
pub noise_amplitude: f64,
pub emd_config: EMDConfig,
pub random_seed: Option<u64>,
}Expand description
Ensemble Empirical Mode Decomposition (EEMD) for improved robustness
Fields
ensemble_size: usizeNumber of ensemble members
noise_amplitude: f64Noise amplitude (as fraction of signal std)
emd_config: EMDConfigEMD configuration
random_seed: Option<u64>Optional seed for random number generation If None, uses a random seed for true randomness If Some(seed), uses the provided seed for reproducibility
Implementations